@@ -2,9 +2,9 @@ package Test::Smoke::Mailer::Mail_Sendmail;
 use warnings;
 use strict;
 
-use base 'Test::Smoke::Mailer::Base';
+our $VERSION = '0.016';
 
-use fallback 'inc';
+use base 'Test::Smoke::Mailer::Base';
 
 =head1 Test::Smoke::Mailer::Mail_Sendmail
 
